]> andersk Git - openssh.git/commitdiff
- markus@cvs.openbsd.org 2001/09/27 15:31:17
authormouring <mouring>
Wed, 3 Oct 2001 17:12:43 +0000 (17:12 +0000)
committermouring <mouring>
Wed, 3 Oct 2001 17:12:43 +0000 (17:12 +0000)
     [auth2.c auth2-chall.c sshconnect1.c]
     typos; from solar

ChangeLog
auth2-chall.c
auth2.c
sshconnect1.c

index a5ec775cdac328f8f6634a2f3b75080b3ec77370..044c511d71eaa92fa20912cb2d0acd991b20b240 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -7,6 +7,9 @@
    - markus@cvs.openbsd.org 2001/09/27 11:59:37
      [packet.c]
      missing called=1; chombier@mac.com
+   - markus@cvs.openbsd.org 2001/09/27 15:31:17
+     [auth2.c auth2-chall.c sshconnect1.c]
+     typos; from solar
 
 20011001
  - (stevesk) loginrec.c: fix type conversion problems exposed when using
index 5afd7d769868eeb4409f19d9e977aafea5ae014f..5e6a691f808920ae778c466b43194953a2e39857 100644 (file)
@@ -23,7 +23,7 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include "includes.h"
-RCSID("$OpenBSD: auth2-chall.c,v 1.7 2001/06/23 15:12:17 itojun Exp $");
+RCSID("$OpenBSD: auth2-chall.c,v 1.8 2001/09/27 15:31:17 markus Exp $");
 
 #include "ssh2.h"
 #include "auth.h"
@@ -139,7 +139,7 @@ kbdint_next_device(KbdintAuthctxt *kbdintctxt)
 }
 
 /*
- * try challenge-reponse, set authctxt->postponed if we have to
+ * try challenge-response, set authctxt->postponed if we have to
  * wait for the response.
  */
 int
diff --git a/auth2.c b/auth2.c
index 39322dc69d00123f15205f195e09c7b4a759a981..c0ed362139df5e831c8d820ec79c9870af4557ac 100644 (file)
--- a/auth2.c
+++ b/auth2.c
@@ -23,7 +23,7 @@
  */
 
 #include "includes.h"
-RCSID("$OpenBSD: auth2.c,v 1.70 2001/09/20 13:46:48 markus Exp $");
+RCSID("$OpenBSD: auth2.c,v 1.71 2001/09/27 15:31:17 markus Exp $");
 
 #include <openssl/evp.h>
 
@@ -122,7 +122,7 @@ do_authentication2()
 
        x_authctxt = authctxt;          /*XXX*/
 
/* challenge-reponse is implemented via keyboard interactive */
        if (options.challenge_response_authentication)
                options.kbd_interactive_authentication = 1;
        if (options.pam_authentication_via_kbd_int)
index 8575081ed2d9160bf1f7848edfc20f00f648fa2f..05cd9f6d688d603ad52c31989a0dcc5ee1253a7a 100644 (file)
@@ -13,7 +13,7 @@
  */
 
 #include "includes.h"
-RCSID("$OpenBSD: sshconnect1.c,v 1.39 2001/07/05 20:32:47 stevesk Exp $");
+RCSID("$OpenBSD: sshconnect1.c,v 1.40 2001/09/27 15:31:17 markus Exp $");
 
 #include <openssl/bn.h>
 #include <openssl/evp.h>
@@ -820,9 +820,9 @@ try_challenge_response_authentication(void)
        u_int clen;
        char prompt[1024];
        char *challenge, *response;
-       
-       debug("Doing challenge reponse authentication.");
-       
+
+       debug("Doing challenge response authentication.");
+
        for (i = 0; i < options.number_of_password_prompts; i++) {
                /* request a challenge */
                packet_start(SSH_CMSG_AUTH_TIS);
@@ -122,7 +122,7 @@ do_authentication2()
        x_authctxt = authctxt;          /*XXX*/
 
-       /* challenge-reponse is implemented via keyboard interactive */
+       /* challenge-response is implemented via keyboard interactive */
        if (options.challenge_response_authentication)
                options.kbd_interactive_authentication = 1;
This page took 0.074365 seconds and 5 git commands to generate.